#include "stdlib.h"
#include "oric.h"
#include "chess.h"

unsigned char turn;
char cursorx, cursory;
char started;
unsigned int clock;

void switch_turn() {
	turn^=COLOR;
	clock= turn==mycolor ? 0xBF64 : 0xBC1C;
}

void inc_my_clock() {
  char min=peek(0xBC1C);
  if (min!='0') poke(0xBC1C,min=='9'?'0':min+1);
  send_char(0x1B); send_char('+');
}

void dec_his_clock() {
  char min=peek(0xBF64);
  if (min!='1') poke(0xBF64,min=='0'?'9':min-1);
  send_char(0x1B); send_char('-');
}
	
void intro_screen(void) {
  const int screen=0xBB80;
  setflags(SCREEN); poke(0x20C,0x7F);
  poke(screen,32); memcpy((char *)screen+1,(char *)screen,28*40);
  poke(screen+80,A_ALT); poke(screen+120,A_ALT); poke(screen+160,A_ALT);
  board[7][3]=KING; display(3,7); board[7][3]=QUEEN|COLOR; display(4,7);
  gotoxy(6,6); printf("\033%c\033%cT e a   F o r   T w o",64+A_STD2H,64+A_FWYELLOW);
  gotoxy(6,7); printf("\033%c\033%cT e a   F o r   T w o",64+A_STD2H,64+A_FWYELLOW);
  gotoxy(12,10); printf("\033%c\033%cB l i t z",64+A_STD2H,64+A_FWYELLOW);
  gotoxy(12,11); printf("\033%c\033%cB l i t z",64+A_STD2H,64+A_FWYELLOW);
  gotoxy(9,15); printf("Fabrice Frances 1995");
}

void read_number(char *number) {
  int i;
  char c;
  do {
    gotoxy(10+i,20);
    c=get();
    if (c==0x7F && i) { 
      i--; 
      gotoxy(10+i,20); putchar(' ');
      gotoxy(10+i,21); putchar(' ');
    }
    if (c==':' || c>='0' && c<='9') {
      putchar(c); gotoxy(10+i,21); putchar(c);
      number[i++]=c;
    }
  } while(c!=0x0D);
  number[i]=0;
}

void link(void) {
  const int screen=0xBB80;
  char c=0; char number[16];
  int i;
  poke(screen+18*40,A_STD2H); poke(screen+19*40,A_STD2H);
  poke(screen+18*40+1,A_FWGREEN); poke(screen+19*40+1,A_FWGREEN);
  gotoxy(0,18); 
  printf("\033%c\033%c1)  N u l l   M o d e m   L i n k",64+A_STD2H,64+A_FWGREEN);
  gotoxy(0,19); 
  printf("\033%c\033%c1)  N u l l   M o d e m   L i n k",64+A_STD2H,64+A_FWGREEN);
  gotoxy(0,20); printf("\033%c\033%c2)  M o d e m   L i n k",64+A_STD2H,64+A_FWGREEN);
  gotoxy(0,21); printf("\033%c\033%c2)  M o d e m   L i n k",64+A_STD2H,64+A_FWGREEN);
  do c=get(); while(c<'1' || c>'2');
  if (c=='1') {
    set_dtr();
    if (carrier_detect()) swap_sides();
  } else {
    set_dtr();
    gotoxy(2,18); printf("1)  C a l l                      ");
    gotoxy(2,19); printf("1)  C a l l                      ");
    gotoxy(2,20); printf("2)  A n s w e r        ");
    gotoxy(2,21); printf("2)  A n s w e r        ");
    do c=get(); while(c<'1' || c>'2');
    if (c=='1') {
      gotoxy(2,18); printf("P h o n e   N u m b e r   ( o p t . )");
      gotoxy(2,19); printf("P h o n e   N u m b e r   ( o p t . )");
      gotoxy(2,20); printf("                       ");
      gotoxy(2,21); printf("                       ");
      setflags(SCREEN|CURSOR);
      read_number(number);
      setflags(SCREEN);
      send_char('A'); send_char('T'); send_char('D'); 
      for(i=0;number[i];i++) send_char(number[i]);
    } else {
      send_char('A'); send_char('T'); send_char('A');
      swap_sides();
    }
    send_char('\015');
    while(!carrier_detect());
  }
}
 
main() {
  char c;
  char fromx, fromy, tox, toy;
  char selected=0, played=0;

  init_comm();
  define_chars();
  intro_screen();
  link();
  init_screen();
  for(;;) {
    c=receive_char();
    if (c==0x1B) { 
      if (opponent_play()) { started=1; switch_turn(); }
    } else if (c!=-1) display_chat(c);
    c=key();
    if (!selected || cursorx!=fromx || cursory!=fromy)
      show_background(cursorx,cursory);
    switch (c) {
      case 0x03:
	if (board[cursory][cursorx]) change_ink();
	else change_paper();
	break;
      case 0x08: if (cursorx) cursorx--; break;
      case 0x09: if (cursorx!=7) cursorx++; break;
      case 0x0A: 
	if (peek(0x209)!=0x38) { chat(0x0A); send_char(0x0A); }
	else if (cursory) cursory--; break;
      case 0x0B: if (cursory!=7) cursory++; break;
      case 0x0D:
	if (peek(0x209)!=0x38) { chat(0x0D); send_char(0x0D); }
	else if (!selected) { fromx=cursorx; fromy=cursory; selected=1; }
	else if (turn==mycolor) { tox=cursorx; toy=cursory; played=1; }
	else ping();
	break;
      case 0x0F: if (!started) inc_my_clock(); break;
      case 0x10: if (!started) dec_his_clock(); break;
      case 0x1B:
	if (selected) {
	  show_background(fromx,fromy);
	  selected=0;
	}
	break;
      case 0x13:
	if (mycolor==0 && !started) {
	  selected=0;
	  swap_sides();
	  send_char('\033'); send_char('S');
	  display_board();
	}
	break;
/*
      case 0x11: 
	gotoxy(0,27); setflags(SCREEN|CURSOR); 
	end_comm(); 
	exit(0);
*/
      default:
	if (c>=32) { chat(c); send_char(c); }
    }
    show_cursor();
    if (played) {
      show_background(fromx,fromy);
      if (valid(fromx,fromy,tox,toy)) {
	move(fromx,fromy,tox,toy);
	send_move(fromx,fromy,tox,toy);
	started=1; switch_turn();
      } else ping();
      selected=played=0;
    }
  }
}

